// KreateCD - CD recording software for the K desktop environment
//
// 1998-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General      
// Public License.  See the file COPYING in the main directory of the       
// KreateCD distribution for more details.                                     

#ifndef CDRWBLANK_INCLUDED
#define CDRWBLANK_INCLUDED

#include <qwidget.h>

#include "ProcessInterface.h"

class CDRWBlank : public ProcessInterface {
  Q_OBJECT;
 public:

  enum BlankMode {Blank_All,Blank_Fast,Blank_Track,Blank_Unreserve,
		  Blank_Tail,Blank_Unclose,Blank_Session};
  int  blankMedia(BlankMode bmode=Blank_All);

  protected :

    virtual bool processStderrLine(char *buffer);
  virtual bool processStdoutLine(char *buffer);
  virtual int processExited(void);
  virtual int  processCleanup(int rval);
  
 private:
  int burnstate;
};

#endif


